@@ -1,7 +1,7 @@
 package File::Create::Layout;
 
-our $DATE = '2015-09-10'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-09-11'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -292,6 +292,23 @@ sub check_layout {
     [200, "OK", $err ? 0:1, {'func.error' => $err}];
 }
 
+$SPEC{parse_layout} = {
+    v => 1.1,
+    summary => 'Parse layout string into a data structure '.
+        'suitable for processing',
+    args => {
+        %arg_layout,
+    },
+};
+sub parse_layout {
+    my %args = @_;
+
+    my $res;
+    eval { $res = _parse_layout($args{layout}) };
+    return [400, "Layout has error(s): $@"] if $@;
+    [200, "OK", $res];
+}
+
 1;
 # ABSTRACT: Quickly create files/directories according to a layout
 
@@ -307,11 +324,15 @@ File::Create::Layout - Quickly create files/directories according to a layout
 
 =head1 VERSION
 
-This document describes version 0.02 of File::Create::Layout (from Perl distribution File-Create-Layout), released on 2015-09-10.
+This document describes version 0.03 of File::Create::Layout (from Perl distribution File-Create-Layout), released on 2015-09-11.
 
 =head1 SYNOPSIS
 
- use File::Create::Layout qw(create_files_using_layout);
+ use File::Create::Layout qw(
+     create_files_using_layout
+     check_layout
+     parse_layout
+ );
 
  my $res = create_files_using_layout(layout => <<'EOL');
  file1.txt
@@ -407,6 +428,34 @@ that contains extra information.
 
 Return value:  (any)
 
+
+=head2 parse_layout(%args) -> [status, msg, result, meta]
+
+Parse layout string into a data structure suitable for processing.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<layout>* => I<str>
+
+Layout.
+
+See the module documentation for the format/specification of layout.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 LAYOUT SPECIFICATION
 
 Layout is a text document containing zero or more lines. Each line is either a
@@ -474,6 +523,10 @@ are not allowed) is used for this:
  file5-in-top-level
  file6
 
+=head1 SEE ALSO
+
+L<Setup::File::Layout>, transactional/undoable version of this module
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/File-Create-Layout>.
